# -*- coding: utf-8 -*-

from rest_framework import serializers

from ... import models
from thx.api.serializers import (
    ThuxListSerializerMixin, ThuxRetrieveSerializerMixin, ThuxCreateSerializerMixin,
    ThuxUpdateSerializerMixin, ThuxPartialUpdateSerializerMixin, ThuxStatusSerializerMixin,
    ThuxEnableSerializerMixin, ThuxDisableSerializerMixin
)


# CURRENCY
class CurrencySerializer(serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_currency_currency'
        model = models.Currency
        fields = '__all__'


class CurrencyListSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_currency_currency_list'
        model = models.Currency
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class CurrencyRetrieveSerializer(ThuxRetrieveSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_currency_currency_retrieve'
        model = models.Currency
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []


class CurrencyCreateSerializer(ThuxCreateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_currency_currency_create'
        model = models.Currency
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []

    def to_representation(self, instance):
        return CurrencyListSerializer(instance, context=self.context).data


class CurrencyUpdateSerializer(ThuxUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_currency_currency_update'
        model = models.Currency
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []

    def to_representation(self, instance):
        return CurrencyRetrieveSerializer(instance, context=self.context).data


class CurrencyPartialUpdateSerializer(ThuxPartialUpdateSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_currency_currency_partial_update'
        model = models.Currency
        exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier')

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []

    def to_representation(self, instance):
        return CurrencyRetrieveSerializer(instance, context=self.context).data


class CurrencyEnableSerializer(ThuxEnableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_currency_currency_enable'
        model = models.Currency
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    def to_representation(self, instance):
        return CurrencyRetrieveSerializer(instance, context=self.context).data


class CurrencyDisableSerializer(ThuxDisableSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_currency_currency_disable'
        model = models.Currency
        fields = ()

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    def to_representation(self, instance):
        return CurrencyRetrieveSerializer(instance, context=self.context).data


class CurrencyLightSerializer(ThuxListSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_currency_currency_light'
        model = models.Currency
        fields = ('code', 'status', 'get_status_display',)

    def get_field_names(self, *args, **kwargs):
        profile = self.context.get('view').kwargs['profile']
        fields = super().get_field_names(*args, **kwargs)
        if profile == 'superuser':
            return fields
        if profile == 'staff':
            return fields
        return []
